Index: /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIMouseHandler.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIMouseHandler.cpp	(revision 35508)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIMouseHandler.cpp	(revision 35509)
@@ -306,4 +306,7 @@
             break;
     }
+
+    /* Notify all listeners: */
+    emit mouseStateChanged(mouseState());
 }
 
@@ -380,6 +383,7 @@
 
     /* Otherwise we should show host pointer with guest shape assigned to it if:
-     * mouse is 'integrated', 'absolute', valid pointer shape is present. */
-    if (uisession()->isMouseIntegrated() &&
+     * machine is NOT 'paused', mouse is 'integrated', 'absolute', valid pointer shape is present. */
+    if (!uisession()->isPaused() &&
+        uisession()->isMouseIntegrated() &&
         uisession()->isMouseSupportsAbsolute() &&
         uisession()->isValidPointerShapePresent())
@@ -393,6 +397,7 @@
 
     /* There could be other states covering such situations as:
      * 1. mouse is 'not captured', 'integrated', 'not absolute' or
      * 2. mouse is 'not captured', 'not integrated', 'absolute'.
      * We have nothing to do with that except just unset the cursor. */
     {
@@ -393,6 +397,7 @@
 
     /* There could be other states covering such situations as:
-     * 1. mouse is 'not captured', 'integrated', 'not absolute' or
-     * 2. mouse is 'not captured', 'not integrated', 'absolute'.
+     * 1. machine is 'paused' or
+     * 2. mouse is 'not captured', 'integrated', 'not absolute' or
+     * 3. mouse is 'not captured', 'not integrated', 'absolute'.
      * We have nothing to do with that except just unset the cursor. */
     {
